==> webcamoid_9.2.3.orig.tar.xz: webcamoid-9.2.3/README.md <==
# Webcamoid, The ultimate webcam suite! #

[Webcamoid](https://webcamoid.github.io/) is a full featured and multiplatform webcam suite.

<a target="_blank" href="https://webcamoid.github.io/"><img src="https://webcamoid.github.io/theme/images/screenshots/Main.webp" style="height: 240px;" /></a>

## Features ##

* Cross-platform (GNU/Linux, Mac, Windows, Android, FreeBSD)
* Take pictures and record videos with the webcam.
* Manages multiple webcams.
* Written in C++ and Qt.
* Custom controls for each webcam.
* Add funny effects to the webcam.
* 60+ effects available.
* Translated to many languages.
* Use custom network and local files as capture devices.
* Capture from desktop.
* Many recording formats.
* Virtual webcam support for feeding other programs (GNU/Linux, Mac, Windows)

## Build and Install ##

Visit the [wiki](https://github.com/webcamoid/webcamoid/wiki) for a comprehensive compile and install instructions.

## Downloads ##

Download the pre-compiled packages for GNU/Linux, Windows, and Android.
If you are a Mac user, consider [making a donation](http://webcamoid.github.io/donations) for buying the needed development hardware and also supporting your platform.

[![Release buidls](http://webcamoid.github.io/theme/images/DownloadButtons/BinaryPackagesButton.png)](https://payhip.com/Webcamoid)

Become a [Webcamoid sponsor](https://github.com/sponsors/hipersayanX) and get early access to the latest features.

[![Daily Build](http://webcamoid.github.io/theme/images/DownloadButtons/DailyBuildButton.png)](https://github.com/sponsors/hipersayanX)

## Donations ##

If you are interested in donating to the project you can look at all available methods in the [donations page](https://webcamoid.github.io/donations).

## Status ##

[![Android](https://github.com/webcamoid/webcamoid/actions/workflows/android.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/android.yml)
[![Arch Linux](https://github.com/webcamoid/webcamoid/actions/workflows/linux-arch.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-arch.yml)
[![Debian](https://github.com/webcamoid/webcamoid/actions/workflows/linux-debian.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-debian.yml)
[![Fedora](https://github.com/webcamoid/webcamoid/actions/workflows/linux-fedora.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-fedora.yml)
[![Mageia](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mageia.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mageia.yml)
[![Linux MinGW](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mingw.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mingw.yml)
[![OpenSUSE](https://github.com/webcamoid/webcamoid/actions/workflows/linux-opensuse.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-opensuse.yml)
[![Ubuntu](https://github.com/webcamoid/webcamoid/actions/workflows/linux-ubuntu.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-ubuntu.yml)
[![Flatpak](https://github.com/webcamoid/webcamoid/actions/workflows/flatpak.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/flatpak.yml)
[![Mac](https://github.com/webcamoid/webcamoid/actions/workflows/mac.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/mac.yml)
[![Windows MSYS](https://github.com/webcamoid/webcamoid/actions/workflows/windows-msys.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/windows-msys.yml)
[![Build status](https://api.cirrus-ci.com/github/webcamoid/webcamoid.svg)](https://cirrus-ci.com/github/webcamoid/webcamoid)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/08a585dc07a14b8bad2bbb39d6628fdd)](https://www.codacy.com/gh/webcamoid/webcamoid/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=webcamoid/webcamoid&amp;utm_campaign=Badge_Grade)
[![Translation status](https://hosted.weblate.org/widgets/webcamoid/-/svg-badge.svg)](https://hosted.weblate.org/engage/webcamoid/?utm_source=widget)
[![Project Stats](https://www.openhub.net/p/Webcamoid/widgets/project_thin_badge.gif)](https://www.openhub.net/p/Webcamoid)
[![Gitlab mirror](https://img.shields.io/badge/mirror-Gitlab-007fff.svg)](https://gitlab.com/hipersayanX/webcamoid/)
[![SourceForge mirror](https://img.shields.io/badge/mirror-SourceForge-007fff.svg)](https://sourceforge.net/p/webcamoid/)

[![Packaging status](https://repology.org/badge/vertical-allrepos/webcamoid.svg)](https://repology.org/metapackage/webcamoid)

## License ##

```
Webcamoid is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Webcamoid is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
```

[![License](https://www.gnu.org/graphics/gplv3-with-text-136x68.png)](https://github.com/webcamoid/webcamoid/blob/master/COPYING)

## Reporting Bugs ##

Report all issues in the [issues tracker](https://github.com/webcamoid/webcamoid/issues).

## Subscribe ##

Stay tuned to new releases with the project [feeds](https://github.com/webcamoid/webcamoid/releases.atom).

==> webcamoid_9.3.0.orig.tar.xz: webcamoid-9.3.0/README.md <==
# Webcamoid, The ultimate webcam suite! #

[Webcamoid](https://webcamoid.github.io/) is a full featured and multiplatform webcam suite.

<a target="_blank" href="https://webcamoid.github.io/"><img src="https://webcamoid.github.io/theme/images/screenshots/Main.webp" style="height: 240px;" /></a>

## Features ##

Unleash your creativity with Webcamoid, the versatile, cross-platform webcam software designed for everyone!  
Available on GNU/Linux, Mac, Windows, Android, and FreeBSD, Webcamoid lets you capture stunning photos and videos with ease. Manage multiple webcams effortlessly, each with customizable controls tailored to your needs.  
Transform your webcam experience with over 60 fun and creative effects to add flair to your videos and snapshots. Whether you're streaming, recording, or just having fun, Webcamoid supports a wide range of recording formats and even lets you use custom network streams or local files as capture sources. Plus, with desktop capture functionality, you can record your screen seamlessly.  
Webcamoid's virtual webcam feature allows you to feed your enhanced video to other programs, making it perfect for video calls, streaming, or content creation on GNU/Linux, Mac, and Windows. Translated into multiple languages, Webcamoid is accessible to users worldwide.  
Download Webcamoid today and turn your webcam into a powerhouse of creativity and functionality!

## Build and Install ##

Visit the [wiki](https://github.com/webcamoid/webcamoid/wiki) for a comprehensive compile and install instructions.

## Downloads ##

Download the pre-compiled packages for GNU/Linux, Windows, and Android.
If you are a Mac user, consider [making a donation](http://webcamoid.github.io/donations) for buying the needed development hardware and also supporting your platform.

[![Release buidls](http://webcamoid.github.io/theme/images/DownloadButtons/BinaryPackagesButton.png)](https://payhip.com/Webcamoid)

Become a [Webcamoid sponsor](https://github.com/sponsors/hipersayanX) and get early access to the latest features.

[![Daily Build](http://webcamoid.github.io/theme/images/DownloadButtons/DailyBuildButton.png)](https://github.com/sponsors/hipersayanX)

## Donations ##

If you are interested in donating to the project you can look at all available methods in the [donations page](https://webcamoid.github.io/donations).

## Pay and get your issue solved quick ##

Import an issue in Bountyhub, set a price and get your issue solved or a feature implemented quick.

[![Webcamoid on BountyHub](https://img.shields.io/badge/Webcamoid-on%20BountyHub-yellow)](https://bountyhub.dev/bounties?repo=webcamoid/webcamoid)

## Donations campaings ##

Do you want to use Webcamoid in MacOs X, you can colabore in the donations campaing for buying MacBook.

[![Go to GoGetFunding](https://img.shields.io/badge/campaign-GoGetFunding-blue?style=for-the-badge)](https://gogetfunding.com/buying-a-macbook-for-webcamoid-macos-development/)

## Status ##

[![Android](https://github.com/webcamoid/webcamoid/actions/workflows/android.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/android.yml)
[![Arch Linux](https://github.com/webcamoid/webcamoid/actions/workflows/linux-arch.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-arch.yml)
[![Debian](https://github.com/webcamoid/webcamoid/actions/workflows/linux-debian.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-debian.yml)
[![Fedora](https://github.com/webcamoid/webcamoid/actions/workflows/linux-fedora.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-fedora.yml)
[![Mageia](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mageia.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mageia.yml)
[![Linux MinGW](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mingw.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-mingw.yml)
[![OpenSUSE](https://github.com/webcamoid/webcamoid/actions/workflows/linux-opensuse.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-opensuse.yml)
[![Ubuntu](https://github.com/webcamoid/webcamoid/actions/workflows/linux-ubuntu.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/linux-ubuntu.yml)
[![Flatpak](https://github.com/webcamoid/webcamoid/actions/workflows/flatpak.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/flatpak.yml)
[![Mac](https://github.com/webcamoid/webcamoid/actions/workflows/mac.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/mac.yml)
[![Windows MSYS](https://github.com/webcamoid/webcamoid/actions/workflows/windows-msys.yml/badge.svg)](https://github.com/webcamoid/webcamoid/actions/workflows/windows-msys.yml)
[![Build status](https://api.cirrus-ci.com/github/webcamoid/webcamoid.svg)](https://cirrus-ci.com/github/webcamoid/webcamoid)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/08a585dc07a14b8bad2bbb39d6628fdd)](https://www.codacy.com/gh/webcamoid/webcamoid/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=webcamoid/webcamoid&amp;utm_campaign=Badge_Grade)
[![Translation status](https://hosted.weblate.org/widgets/webcamoid/-/svg-badge.svg)](https://hosted.weblate.org/engage/webcamoid/?utm_source=widget)
[![Project Stats](https://www.openhub.net/p/Webcamoid/widgets/project_thin_badge.gif)](https://www.openhub.net/p/Webcamoid)
[![Gitlab mirror](https://img.shields.io/badge/mirror-Gitlab-007fff.svg)](https://gitlab.com/hipersayanX/webcamoid/)
[![SourceForge mirror](https://img.shields.io/badge/mirror-SourceForge-007fff.svg)](https://sourceforge.net/p/webcamoid/)

[![Packaging status](https://repology.org/badge/vertical-allrepos/webcamoid.svg)](https://repology.org/metapackage/webcamoid)

## License ##

```
Webcamoid is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Webcamoid is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
```

[![License](https://www.gnu.org/graphics/gplv3-with-text-136x68.png)](https://github.com/webcamoid/webcamoid/blob/master/COPYING)

## Reporting Bugs ##

Report all issues in the [issues tracker](https://github.com/webcamoid/webcamoid/issues).

## Subscribe ##

Stay tuned to new releases with the project [feeds](https://github.com/webcamoid/webcamoid/releases.atom).
